Collected To-do items — Stylist 0.3.dev1 documentation

# Collected To-do items

Looking for some ideas on what needs work? As well as the project ticket database you could consider these “to-do” items.

Todo

This is just a stub to illustrate how it would be done. It is not useable.

(The original entry is located in /net/home/h06/mhambley/Projects/stylist/source/stylist/source.py:docstring of stylist.source.CSource, line 3.)

Todo

This functionality might be provided by fparser at some point.

(The original entry is located in /net/home/h06/mhambley/Projects/stylist/source/stylist/source.py:docstring of stylist.source.FortranSource.find_all, line 13.)

Todo

This functionality might be provided by fparser at some point.

(The original entry is located in /net/home/h06/mhambley/Projects/stylist/source/stylist/source.py:docstring of stylist.source.FortranSource.path, line 14.)